from setuptools import setup, find_packages

with open("README.md", "r") as fh:
    long_description = fh.read()

setup(
    name="realestateapplication",
    version="0.2.0",
    author="Rajkumar",
    author_email="pmrajkumar30@gmail.com",
    description="A simple calculation for the realestate application",
    long_description=long_description,
    url="",
    packages=find_packages(),
    keywords='splittercalculation',
    classifiers=[
        "Development Status :: 3 - Alpha",
        "Programming Language :: Python :: 3",
        "License :: OSI Approved :: MIT License",
        "Operating System :: OS Independent",
    ],
    python_requires='>=3.6',
    install_requires=[
        # add any dependencies required by your package here
    ],
)


import re

class Validation:
    def __init__(self, data):
        self.data = data

    def validate(self):
        errors = []
        errors += self.validate_username()
        errors += self.validate_password()
        errors += self.confirm_password()
        return errors

    def validate_username(self):
        errors = []
        print(self.data)
        username = self.data.get('username',[''])
        print(username)
        if not username:
            errors.append("Username is required")
        if len(username) < 3:
            errors.append("Username must be at least 3 characters long")
        if not re.match("^[A-Za-z0-9]*$", username):
            errors.append("Username must not contain special characters")
        return errors

    def validate_password(self):
        errors = []
        password = self.data.get('password',[''])
        if not password:
            errors.append("Password is required")
        elif len(password) <= 8:
            errors.append("Password must be more than 8 characters long")
        return errors

    def confirm_password(self):
        errors = []
        password = self.data.get('password',[''])
        password2 = self.data.get('password2',[''])
        if password != password2:
            errors.append("Passwords do not match")
        return errors